/* --- Copyright University of Birmingham 1998. All rights reserved. ------
 > File:            /bham/common/system/templates/user.poplog/Poplib/vedkeys.p
 > Purpose:			Set up some convenient key bindings
 > Author:          Aaron Sloman, April 23 1993
 > 					Updated 2 Mar 1998
 > documentation: 	Below
 > Related Files:
 */

/*
This file can be copied to your $poplib directory. (By default that is
your login directory.)

It defines a procedure vedkeys that can be compiled and run by the
user-defined procedure vedinit, when VED starts up, to extend the
key mappings you use. The ones given below are only examples that
might be useful for someone regularly switching between different
keyboards who wants some set of frequently used VED operations to
be mapped onto otherwise unused key sequences.

See also HELP * VEDKEYS, HELP * VEDNEWKEYS, HELP * TERMINAL

vedinit could be defined thus

define vedinit;
	;;; If the definition below is not already in your vedinit.p file...
    unless isprocedure(vedkeys) then
        compile('$poplib/vedkeys.p');
    endunless;

    vedkeys();

	.... additional instructions ....

enddefine;


*/

vars vedkeys;

define lconstant vedsetcommand(string);
	;;; set up the command, and leave cursor to right of it
	vedputcommand(string);
	unless vedonstatus then vedstatusswitch() endunless;
	vedtextright();
	vedcharright()
enddefine;


define ved_copy_t =
	ved_copy <> ved_t
enddefine;


define vedkeys();

	;;; for use in mail files. See HELP * VED_GETMAIL
	vedsetkey('\^[6', "ved_ccm");		;;; ESC 6 -- clear current message
	vedsetkey('\^[7', "ved_tmh");		;;; ES7 5 -- tidy mail headers
	vedsetkey('\^[8', "ved_nm");		;;; ESC 8 -- next message
	vedsetkey('\^[\^[8', "ved_lm");		;;; ESC ESC 8 -- last message

	vedsetkey('\^[1', "ved_gn");		;;; ESC 1 - Get News (ENTER gn)

	;;; ESC DEL join current line to previous one
	vedsetkey('\^[\^?', "vedjoinline");

	vedset keys
		;;; extensions to vednewkeys

		"ENTER m"		= esc -			;;; only one thing after move

		"ENTER copy_t"  = esc =     	;;; two things exist after copy

		"capword"		= '\^[\'c'		;;; Capital initial letter: ESC ' c

		"prevpara" 		= '\^[\'['

		"nextpara" 		= '\^[\']'

		"prevsent" 		= '\^[\'{'

		"nextsent" 		= '\^[\'}'

		"ENTER break"	= '\^[\'b'		;;; Toggle break mode

		"ENTER exchangeposition" 	= '\^[\'s'

		"xrefresh"		= ctrl l	;;; Needed after changing window size
	endvedset;

;;; A collection of things using dired, starting ESC ;
;;; pity we can't used "vedset keys" with closures.

	;;; expand path pattern
	vedsetkey('\^[;;', veddo(%'dired'%)); 		;;;= esc ; ;

	;;; unexpand expanded directory
	vedsetkey('\^[;u', veddo(%'dired -dcd'%)); 	;;;= esc ; u
	
	;;; re-use current buffer when getting a file
	vedsetkey('\^[;q', veddo(%'qdired'%)); 	;;; = esc ; q

	;;; get long directory listing
	vedsetkey('\^[;l', veddo(%'dired -l'%));	;;; = esc ; l

	;;; Ditto, in reverse chronological order
	vedsetkey('\^[;t', veddo(%'dired -lt'%));	;;; = esc ; t

	;;; list directories only
	vedsetkey('\^[;d', veddo(%'dired -d'%));	;;; = esc ; d

	;;; remove the file on current line
	vedsetkey('\^[;r', veddo(%'dired -rm'%));	;;;= esc ; r

	;;; Prepare dired commands for user to complete
	vedsetkey('\^[;m', vedsetcommand(%'dired -mv'%));	;;; = esc ; m
	vedsetkey('\^[;M', vedsetcommand(%'dired -mvd'%));	;;; = esc ; M
	vedsetkey('\^[;c', vedsetcommand(%'dired -cp'%));	;;; = esc ; c
	vedsetkey('\^[;C', vedsetcommand(%'dired -cpd'%));	;;; = esc ; C
	vedsetkey('\^[;g', vedsetcommand(%'dired -grep'%));	;;; = esc ; g


enddefine;
